@@ -13,8 +13,8 @@ from os import getcwd, path as op
 # Module information
 # ==================
 
-__version__ = '0.4.1'
-__project__ = 'Starter'
+__version__ = "0.4.2"
+__project__ = "Starter"
 __author__ = "Kirill Klenov <horneds@gmail.com>"
 __license__ = "BSD"
 
